@@ -110,7 +110,7 @@ def time_till_metrics(vals, expected_dt, truth_val):
 #     })
 
 
-def validity_nondecreasing_smoothness(series):
+def validity_nondecreasing_smoothness(series, *args, **kwargs):
     orig_diffs = series.diff()
     rises = [abs(diff) for diff in orig_diffs if diff > 0]
     inds = [ind for ind, diff in enumerate(orig_diffs) if diff > 0]
@@ -122,7 +122,7 @@ def validity_nondecreasing_smoothness(series):
     return sum([rise * run / 2 for rise, run in zip(rises, runs)])
 
 
-def validity_nondecreasing(series):
+def validity_nondecreasing(series, *args, **kwargs):
     """Checks if values are nondecreasing.
     Return number of times a decrease occurs"""
     return len(series[series.diff() < 0])
@@ -165,14 +165,24 @@ def apply_to_updates(func):
     :param func:
     :return: func
     """
-
     def over_updates(data_df, truth_df, expected_df, *args, **kwargs):
-        rot_func = apply_to_observations(func)
-        return rot_func(data_df.T, truth_df.T, expected_df.T, *args, **kwargs)
+        dct = {}
+
+        for update, series in data_df.iteritems():
+
+            not_na = series[series.notna()]
+            if len(not_na) == 0:
+                dct[update] = {}
+
+            else:
+                dct[update] = func(series, truth_df, expected_df, *args, **kwargs)
+
+        return pd.DataFrame.from_dict(dct, orient='columns')
 
     return over_updates
 
 
+
 def timeliness(data_df, truth_df, expected_df):
     """
 
@@ -200,12 +210,16 @@ def accuracy(data_df, truth_df, expected_df):
 
 
 def validity(data_df, truth_df, expected_df):
-    func = apply_to_updates(validity_nondecreasing_smoothness)
-    df = func(data_df, truth_df, expected_df)
-    func = apply_to_updates(validity_nondecreasing)
-    df2 = func(data_df, truth_df, expected_df)
-    final_df = pd.concat([df, df2], axis=1)
-    return final_df
+    def validity_metrics(series, truth_df, expected_df):
+        return {
+            "ValidityNondecreasingSmoothness":
+                validity_nondecreasing_smoothness(series, truth_df, expected_df),
+            "ValidityNondecreasingUpdates":
+                validity_nondecreasing(series, truth_df, expected_df)
+        }
+
+    func = apply_to_updates(validity_metrics)
+    return func(data_df, truth_df, expected_df)
 
 
 #
